/* src/4ti2/4ti2_config.h.  Generated from 4ti2_config.h.in by configure.  */
/* Define if GMP (with C++ interface) is installed */
#define _4ti2_HAVE_GMP /**/

/* Define if we can convert between int32_t and mpz_class */
#define _4ti2_HAVE_MPZ_INT32_CONVERSION 1

/* Define if we can convert between int64_t and mpz_class */
#define _4ti2_HAVE_MPZ_INT64_CONVERSION 1
